/*
 *  Eukleides version 1.5.4
 *  Copyright (c) Christian Obrecht 2004-2010
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

void create_set(_param p);

void create_segment(_param p);

void add_head_point(_param p);

void add_tail_point(_param p);

void catenate_sets(_param p);

void push_point(_param p);

void extract_point(_param p);

void extract_subset(_param p);

void create_polygon(_param p);

void translate_set(_param p);

void reflect_set(_param p);

void symetric_set(_param p);

void rotate_set(_param p);

void homothetic_set(_param p);

void set_cardinal(_param p);

void path_length(_param p);

void polygon_area(_param p);

void create_centroid(_param p);

void segment_argument(_param p);

void vertex_angle(_param p);

void triangle_height(_param p);
